# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.0.7] - 2020-09-01 [BETA]
### Added
-Long Description fixed

## [0.0.6] - 2020-09-01 [BETA]
### Added
-Long Description added

## [0.0.5] - 2020-09-01 [BETA]
### Added
-Skyhawk logo added on initialization
-Training error fixed

## [0.0.4] - 2020-09-01 [BETA]
### Changed
-Fixed pip install error 


## [0.0.3] - 2020-09-01 [BETA]
### Added
-Better way of storing user data
-Skyhawk init command

### Changed
-Changelog moved from txt to MarkDown

### Removed
-Cascades removed 


## [0.0.2] - 2020-08-31 [BETA]
### Changed
-Fixed pip install error 


## [0.0.1] - 2020-08-31 [BETA]
### Added
-Facial recognition
-Training
-Capturing Data from a webcam
-View user Data
-Delete user Data


